﻿namespace ExceptionsLeadingToInvalidState {

	record class ShoppingCartItem {
		public int BookId { get; set; }
		public int Count { get; set; }
	}

	class ShoppingCart {
		public required int CustomerId { get; set; }
		public List<ShoppingCartItem> Items = new();

		public void ProcessAddRequest(string request) {
			var item = new ShoppingCartItem();
			Items.Add(item);
			
			var tokens = request.Split(' ');
			// TODO: Check for "add" command.
			item.BookId = int.Parse(tokens[1]);
			item.Count = int.Parse(tokens[2]);
			// FIXME: Remove item in case of failure.
		}
	}

	internal class Program {
		private static ShoppingCart s_ShoppingCart = new ShoppingCart { CustomerId = 1 };

		private static void ExecuteRequest(string request) {
			try {
				s_ShoppingCart.ProcessAddRequest(request);
                Console.WriteLine("Request processed, shopping cart content:");
				foreach (var item in s_ShoppingCart.Items) {
                    Console.WriteLine($"  {item}");
                }
            } catch (Exception ex) {
				if (ex is FormatException or OverflowException or IndexOutOfRangeException) {
					Console.WriteLine("Invalid request.");
				} else {
					throw;
				}
			}
		}

		private static void Main(string[] args) {
			ExecuteRequest("add 5 2");
			ExecuteRequest("add Lord of the Rings 2");
			ExecuteRequest("add 3 1");
		}
	}
}
