﻿namespace ExceptionsDefensiveProgramming {

	record class ShoppingCartItem {
		public required int BookId { get; set; }
		public required int Count { get; set; }
	}

	class ShoppingCart {
		public required int CustomerId { get; set; }
		public List<ShoppingCartItem> Items = new();

		public void ProcessAddRequest(string request) {
			var tokens = request.Split(' ');
			// TODO: Check for "add" command.
			var item = new ShoppingCartItem {
				BookId = int.Parse(tokens[1]),
				Count = int.Parse(tokens[2])
			};

			Items.Add(item);
		}
	}

	internal class Program {
		private static ShoppingCart s_ShoppingCart = new ShoppingCart { CustomerId = 1 };

		private static void ExecuteRequest(string request) {
			try {
				s_ShoppingCart.ProcessAddRequest(request);
				Console.WriteLine("Request processed, shopping cart content:");
				foreach (var item in s_ShoppingCart.Items) {
					Console.WriteLine($"  {item}");
				}
			} catch (Exception ex) {
				if (ex is FormatException or OverflowException or IndexOutOfRangeException) {
					Console.WriteLine("Invalid request.");
				} else {
					throw;
				}
			}
		}

		private static void Main(string[] args) {
			ExecuteRequest("add 5 2");
			ExecuteRequest("add Lord of the Rings 2");
			ExecuteRequest("add 3 1");
		}
	}
}
